@@ -298,7 +298,9 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
 
   ndof=int(np1*np2,8)*np3-1
   anu=(chisq-ndof)/sqrt(float(ndof))
-  if (myid==0) print*,'ic4 white noise: chisq, dof, nu=',real(chisq),ndof,anu
+  if (myid==0) &
+       write(*,'(a,f15.8,i15,es15.8)') 'ic4 white noise: chisq, dof, nu=', &
+       & real(chisq),ndof,anu
   !  Transform noise to k-space.
   call fft_mpi(plan,f,total_local_size)
 
@@ -482,7 +484,8 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
   call mpi_reduce(lfm,fm,1,mpi_real,mpi_max,0,mpi_comm_world,ierr)
   if (myid==0) then
      print*,'Statistics of ic4 for idim, itide=',idim,itide
-     print*,'   Mean sigma, sampled sigma, maximum=',real(chisq), &
+     write(*,'(a,3f15.8)') &
+          & '   Mean sigma, sampled sigma, maximum=',real(chisq), &
           &    real(sigma),fm
   endif
   return
