@@ -600,7 +600,7 @@ subroutine pini
            write(*,*) 'Enter Omega_m, Omega_v, H0 (km/s/Mpc,', &
                 &               ' set H0=1 for scale-free case)'
            read(*,*) omegam,omegav,h0
-           print*, omegam,omegav,h0
+           write(*,'(3f15.8)') omegam,omegav,h0
         endif
         call mpi_bcast(omegam,1,mpi_real,0,mpi_comm_world,ierr)
         call mpi_bcast(omegav,1,mpi_real,0,mpi_comm_world,ierr)
@@ -610,12 +610,13 @@ subroutine pini
            if (myid==0) then
               write(*,*) 'Enter Omega_b'
               read(*,*) omegab
-              print*, omegab
+              write(*,'(f15.8)') omegab
            end if
            call mpi_bcast(omegab,1,mpi_real,0,mpi_comm_world,ierr)
         endif
      end if
-     if (myid==0) print*,' Initializing power spectrum for Omega_m, ', &
+     if (myid==0) &
+          write(*,'(a,a,3f15.8)')' Initializing power spectrum for Omega_m, ', &
           & 'Omega_v, H0=',omegam,omegav,h0
      om=omegam
      ov=omegav
@@ -634,7 +635,7 @@ subroutine pini
      write(*,*) 'Enter long-wave spectral index n (scale-invariant', &
           &             ' is n=1)'
      read(*,*) an
-     print*, an
+     write(*,'(f15.8)') an
   endif
   call mpi_bcast(an,1,mpi_integer,0,mpi_comm_world,ierr)
   !     an=1
@@ -819,7 +820,7 @@ subroutine pini
      sig0=fourpi*rombin(dsig8,0.0d0,akmax,1.0d-7)
      pnorm=sigma8**2/sig0
      qrmsps=tcmb*sqrt(pnorm*qq)
-     if (myid==0) write(*,*) 'Qrms-ps/micro-K=',qrmsps
+     if (myid==0) write(*,'(a,f15.8)') 'Qrms-ps/micro-K=',qrmsps
   end if
 
   if (myid==0) then
@@ -831,7 +832,7 @@ subroutine pini
      write(*,*) 'Enter 0,0 if you don''t want the power spectrum', &
           &             ' written to a file'
      read(*,*) ak1,ak2
-     print*, ak1,ak2
+     write(*,'(2es15.8)') ak1,ak2
   endif
 
   call mpi_bcast(ak1,1,mpi_real,0,mpi_comm_world,ierr)
@@ -1220,7 +1221,7 @@ function rombin(f,a,b,tol)
 
        if (Tcmb.le.0) Tcmb=2.728
        if (omhh.le.0.0) then
-          write(6,*) 'TFset_parameters(): Illegal input'
+          write(*,*) 'TFset_parameters(): Illegal input'
           stop
        end if
 
@@ -1273,7 +1274,7 @@ function rombin(f,a,b,tol)
        beta_node = 8.41*omhh**(0.435)
 
        if (k.le.0) then
-          write(6,*) 'TFtransfer_function(): Illegal k'
+          write(*,*) 'TFtransfer_function(): Illegal k'
           stop
        end if
 
